% Produce plots
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%      Exact numerical integration of the master     %%%%%%%%%%%%
%%%%%%%%%%%        equation in some models of stochastic       %%%%%%%%%%%%
%%%%%%%%%%%                     epidemiology                   %%%%%%%%%%%%
%%%%%%%%%%%              FIGURE GENERATION SOFTWARE            %%%%%%%%%%%%
%%%%%%%%%%%             Authors: Jenkinson/Goutsias            %%%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 01/13/2012             %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Save movie as GIF
%
if saveMovie
    imwrite(im,map,'results/SIR.gif','DelayTime',0,'LoopCount',inf)
end

%
% Make figure with exact means and variances
%

hNew = figure('Position',[50 50 900 650]);

%
% plot susceptibles
%
shigh = meanS+standDevS;
slow  = meanS-standDevS;
subplot(2,2,1);
plot(timePoints,meanS,'k','Linewidth',2);
hold on;
subplot(2,2,1);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(2,2,1);
plot(timePoints,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('susceptible pupils (S)')
axis([0 25 0 763])
title('{\bf exact}')

%
% plot infected
%
shigh = meanI+standDevI;
slow  = meanI-standDevI;
subplot(2,2,2);
plot(timePoints,meanI,'k','Linewidth',2);
hold on;
subplot(2,2,2);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(2,2,2);
plot(dataTime,dataPoints,'ro','MarkerEdgeColor','r',...
            'MarkerFaceColor','r','MarkerSize',8)
subplot(2,2,2);
plot(timePoints,slow,'k--','Linewidth',2);
legend('mean','\pm1 standard deviation','data')
xlabel('time (days)');ylabel('infected pupils (I)')
axis([0 25 0 350])
title('{\bf exact}')

%
% plot resistant
%
shigh = meanR+standDevR;
slow  = meanR-standDevR;
subplot(2,2,3);
plot(timePoints,meanR,'k','Linewidth',2);
hold on;
subplot(2,2,3);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(2,2,3);
plot(timePoints,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('recovered pupils (R)')
axis([0 25 0 763])
title('{\bf exact}')

%
% plot Monte Carlo estimates
%
shigh = meanInfected+stdInfected;
slow  = meanInfected-stdInfected;
subplot(2,2,4);
plot(Gilltime,meanInfected,'k','Linewidth',2);
hold on;
subplot(2,2,4);
plot(Gilltime,shigh,'k--','Linewidth',2);
subplot(2,2,4);
plot(Gilltime,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('infected pupils (I)')
axis([0 25 0 350])
title('{\bf estimated}')

saveas(hNew,'results/SIRaverages_1.fig')

%
% Make figure with all Monte Carlo estimates
%

hNewest = figure('Position',[50 50 900 900]);

%
% plot susceptibles
%
shigh = meanS+standDevS;
slow  = meanS-standDevS;
subplot(3,2,1);
plot(timePoints,meanS,'k','Linewidth',2);
hold on;
subplot(3,2,1);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(3,2,1);
plot(timePoints,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('susceptible pupils (S)')
axis([0 25 0 763])
title('{\bf exact}')

% plot infected
shigh = meanI+standDevI;
slow  = meanI-standDevI;
subplot(3,2,3);
plot(timePoints,meanI,'k','Linewidth',2);
hold on;
subplot(3,2,3);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(3,2,3);
plot(timePoints,slow,'k--','Linewidth',2);
legend('mean','\pm1 standard deviation')
xlabel('time (days)');
ylabel('infected pupils (I)')
axis([0 25 0 350])
title('{\bf exact}')

%
% Plot resistant
%
shigh = meanR+standDevR;
slow  = meanR-standDevR;
subplot(3,2,5);
plot(timePoints,meanR,'k','Linewidth',2);
hold on;
subplot(3,2,5);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(3,2,5);
plot(timePoints,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('recovered pupils (R)')
axis([0 25 0 763])
title('{\bf exact}')

% plot estimated susceptibles
shigh = meanSusc+stdSusc;
slow  = meanSusc-stdSusc;
subplot(3,2,2);
plot(Gilltime,meanSusc,'k','Linewidth',2);
hold on;
subplot(3,2,2);
plot(Gilltime,shigh,'k--','Linewidth',2);
subplot(3,2,2);
plot(Gilltime,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('susceptible pupils (S)')
axis([0 25 0 763])
title('{\bf estimated}')

%
% plot estimated infected
%
shigh = meanInfected+stdInfected;
slow  = meanInfected-stdInfected;
subplot(3,2,4);
plot(Gilltime,meanInfected,'k','Linewidth',2);
hold on;
subplot(3,2,4);
plot(Gilltime,shigh,'k--','Linewidth',2);
subplot(3,2,4);
plot(Gilltime,slow,'k--','Linewidth',2);
legend('mean','\pm1 standard deviation')
xlabel('time (days)');
ylabel('infected pupils (I)')
axis([0 25 0 350])
title('{\bf estimated}')

% plot estimated resistant
shigh = meanResis+stdResis;
slow  = meanResis-stdResis;
subplot(3,2,6);
plot(Gilltime,meanResis,'k','Linewidth',2);
hold on;
subplot(3,2,6);
plot(Gilltime,shigh,'k--','Linewidth',2);
subplot(3,2,6);
plot(Gilltime,slow,'k--','Linewidth',2);
xlabel('time (days)');
ylabel('recovered pupils (R)')
axis([0 25 0 763])
title('{\bf estimated}')

saveas(hNewest,'results/SIRaverages_2.fig')

hNew = figure('Position',[200 200 600 600]);

%
% plot probability of R given I>0
%
shigh = meanRcond+standDevRcond;
slow  = meanRcond-standDevRcond;
subplot(2,1,1);
plot(timePoints,meanRcond,'k','Linewidth',2);
hold on;
subplot(2,1,1);
plot(timePoints,shigh,'k--','Linewidth',2);
subplot(2,1,1);
plot(timePoints,slow,'k--','Linewidth',2);
legend('mean','\pm1 standard deviation','Location','SouthEast')
xlabel('time (days)');
ylabel('recovered pupils (given I>0)')
title('{\bf Pr[R|I>0]}')
axis([0 25 0 763])

%
% plot Fano factor
%

shigh = meanRcond+standDevRcond;
slow  = meanRcond-standDevRcond;
subplot(2,1,2);
plot([0;timePoints],[1;(standDevRcond.^2)./meanRcond],'k','Linewidth',2);
xlabel('time (days)');
ylabel('Fano factor')
axis([0 25 0 70])
title('{\bf Pr[R|I>0]}')

saveas(hNew,'results/RgivenI.fig')